package uk.ac.bbsrc.babraham.SparkSpotter;
/*
 * SparkSpotter - An ImageJ plugin for finding bright sparks in movies
 * Copyright (c) 2007 Simon Andrews

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
public class SparkEvent {
	private int startFrame;
	private int endFrame;
	private double totalIntensity;
	private double totalFold;
	private int frameCount;
	private int x;
	private int y;
	private int [] rawData;
	private int [] correctedData;
	private int maxRaw;
	private int minRaw;
	private int maxCorrected;
	private int minCorrected;
	
	public SparkEvent (int frame, double intensity, double fold, int x, int y, int [] correctedData, int [] rawData) {
		startFrame = frame;
		endFrame = frame;
		this.rawData = rawData;
		this.correctedData = correctedData;
		totalIntensity = intensity;
		totalFold = fold;
		frameCount = 1;
		this.x = x;
		this.y = y;
		
		// Find the max and min values
		maxRaw = rawData[0];
		minRaw = rawData[0];
		maxCorrected = correctedData[0];
		minCorrected = correctedData[0];
		
		for (int i=1;i<rawData.length;i++) {
			if (rawData[i]>maxRaw)maxRaw=rawData[i];
			if (rawData[i]<minRaw)minRaw=rawData[i];

			if (correctedData[i]>maxCorrected)maxCorrected=correctedData[i];
			if (correctedData[i]<minCorrected)minCorrected=correctedData[i];
		}
		
	}
	
	public void continueEvent (int frame, double intensity, double fold) {
		endFrame = frame;
		totalIntensity += intensity;
		totalFold += fold;
		frameCount++;
	}
	
	public int startFrame () {
		return startFrame;
	}
	
	public int endFrame () {
		return endFrame;
	}
	
	public double averageIntensity () {
		return totalIntensity/frameCount;
	}
	
	public double averageFold () {
		return totalFold/frameCount;
	}
	
	public int [] rawData () {
		return rawData;
	}
	
	public int [] correctedData () {
		return correctedData;
	}
	
	public int getX () {
		return x;
	}
	public int getY () {
		return y;
	}
	public int maxRaw () {
		return maxRaw;
	}
	public int minRaw () {
		return minRaw;
	}
	public int maxCorrected () {
		return maxCorrected;
	}
	public int minCorrected () {
		return minCorrected;
	}
	
}
